@@ -37,7 +37,6 @@ from locsms.db import model as locsms
 
 import edbob
 from edbob.time import localize
-from edbob.util import requires_impl
 
 from rattail.gpc import GPC
 from rattail.db import Session
@@ -130,9 +129,8 @@ class DataLoader(object):
         self.sms_session = sms_session
 
     @property
-    @requires_impl(is_property=True)
     def sms_class(self):
-        pass
+        raise NotImplementedError
 
     @property
     def name(self):
