@@ -40,6 +40,8 @@ class SMSWriter(sil.Writer):
 
     def write(self, string):
         string = string.replace(os.linesep, '\r\n')
+        if isinstance(string, unicode):
+            string = string.encode('latin_1')
         self.fileobj.write(string)
 
     def write_batch_header(self, **kwargs):
